.. _module-docs:

SymPy Modules Reference
=======================

.. module:: sympy

Because every feature of SymPy must have a test case, when you are not sure how
to use something, just look into the ``tests/`` directories, find that feature
and read the tests for it, that will tell you everything you need to know.

Most of the things are already documented though in this document, that is
automatically generated using SymPy's docstrings.

Click the  "modules" (:ref:`modindex`) link in the top right corner to easily
access any SymPy module, or use the list below:

.. toctree::
   :maxdepth: 2

   abc.rst
   algebras.rst
   assumptions/index.rst
   calculus/index.rst
   categories.rst
   codegen.rst
   combinatorics/index.rst
   concrete.rst
   core.rst
   crypto.rst
   diffgeom.rst
   solvers/diophantine.rst
   discrete.rst
   evalf.rst
   functions/index.rst
   geometry/index.rst
   holonomic/index.rst
   simplify/hyperexpand.rst
   solvers/inequalities.rst
   integrals/integrals.rst
   integrals/g-functions.rst
   interactive.rst
   liealgebras/index.rst
   logic.rst
   matrices/index.rst
   ntheory.rst
   numeric-computation.rst
   solvers/ode.rst
   parsing.rst
   solvers/pde.rst
   physics/index.rst
   plotting.rst
   polys/index.rst
   printing.rst
   rewriting.rst
   series/index.rst
   sets.rst
   simplify/simplify.rst
   solvers/solvers.rst
   solvers/solveset.rst
   stats.rst
   tensor/index.rst
   testing/index.rst
   utilities/index.rst
   vector/index.rst

Contributions to Docs
---------------------

All contributions are welcome. If you'd like to improve something, look into
the sources if they contain the information you need (if not, please fix them),
otherwise the documentation generation needs to be improved (look in the
``doc/`` directory).
